Documentation
¶
Index ¶
- Variables
- func Close(s Interface) error
- type CAS
- func (c *CAS) Close() error
- func (c *CAS) Delete(ctx context.Context, key string) error
- func (c *CAS) Exists(ctx context.Context, key string) error
- func (c *CAS) Get(ctx context.Context, key string) ([]byte, error)
- func (c *CAS) List(ctx context.Context, prefix string) ([]string, error)
- func (c *CAS) Set(ctx context.Context, key string, value []byte) error
- type Closer
- type DirectFile
- func (d *DirectFile) Delete(ctx context.Context, key string) error
- func (d *DirectFile) Exists(ctx context.Context, key string) error
- func (d *DirectFile) Get(ctx context.Context, key string) ([]byte, error)
- func (d *DirectFile) List(ctx context.Context, prefix string) ([]string, error)
- func (d *DirectFile) Set(ctx context.Context, key string, value []byte) error
- type Interface
- type JSON
- func (j *JSON[T]) Delete(ctx context.Context, key string) error
- func (j *JSON[T]) Exists(ctx context.Context, key string) error
- func (j *JSON[T]) Get(ctx context.Context, key string) (T, error)
- func (j *JSON[T]) List(ctx context.Context, prefix string) ([]string, error)
- func (j *JSON[T]) Set(ctx context.Context, key string, value T) error
- type JSONMutexDB
- func (j *JSONMutexDB) Close() error
- func (j *JSONMutexDB) Delete(ctx context.Context, key string) error
- func (j *JSONMutexDB) Exists(ctx context.Context, key string) error
- func (j *JSONMutexDB) Get(ctx context.Context, key string) ([]byte, error)
- func (j *JSONMutexDB) List(ctx context.Context, prefix string) ([]string, error)
- func (j *JSONMutexDB) Set(ctx context.Context, key string, value []byte) error
- type S3API
- func (s *S3API) Delete(ctx context.Context, key string) error
- func (s *S3API) Exists(ctx context.Context, key string) error
- func (s *S3API) Get(ctx context.Context, key string) ([]byte, error)
- func (s *S3API) List(ctx context.Context, prefix string) ([]string, error)
- func (s *S3API) Set(ctx context.Context, key string, value []byte) error
Constants ¶
This section is empty.
Variables ¶
var ( // ErrNotFound is returned when the store implementation cannot find the value // for a given key. ErrNotFound = errors.New("store: key not found") // ErrCantDecode is returned when a store adaptor cannot decode the store format // to a value used by the code. ErrCantDecode = errors.New("store: can't decode value") // ErrCantEncode is returned when a store adaptor cannot encode the value into // the format that the store uses. ErrCantEncode = errors.New("store: can't encode value") // ErrBadConfig is returned when a store adaptor's configuration is invalid. ErrBadConfig = errors.New("store: configuration is invalid") )
Functions ¶
Types ¶
type Closer ¶
type Closer interface {
Close() error
}
Closer is an optional interface for stores that need explicit cleanup. Use Close() to safely close a store, which will call Close() on the underlying store if it implements Closer, otherwise it does nothing.
type DirectFile ¶
type DirectFile struct {
// contains filtered or unexported fields
}
type Interface ¶
type Interface interface {
// Delete removes a value from the store by key.
Delete(ctx context.Context, key string) error
// Exists returns nil if the key exists, ErrNotFound if it does not exist.
Exists(ctx context.Context, key string) error
// Get returns the value of a key assuming that value exists and has not expired.
Get(ctx context.Context, key string) ([]byte, error)
// Set puts a value into the store that expires according to its expiry.
Set(ctx context.Context, key string, value []byte) error
// List lists the keys in this keyspace optionally matching by a prefix.
List(ctx context.Context, prefix string) ([]string, error)
}
Interface defines the calls that Anubis uses for storage in a local or remote datastore. This can be implemented with an in-memory, on-disk, or in-database storage backend.
func NewDirectFile ¶
func NewJSONMutexDB ¶
type JSONMutexDB ¶
type JSONMutexDB struct {
// contains filtered or unexported fields
}
func (*JSONMutexDB) Close ¶
func (j *JSONMutexDB) Close() error
Click to show internal directories.
Click to hide internal directories.